import json,datetime
import copy,uuid,os
from ecomshared.helpers import Encoder,get_source


def create_event( detail_type:str,detail:dict,EVENT_BUS_NAME) ->  dict:
  
    """ create Event Bridge event from input """
    event_bridge_event = {
        "Time" : datetime.datetime.now(),
        "Source" : "ecommerce.warehouse.validate",
        "Resources" : [],
        "DetailType" : detail_type,
        "Detail" : json.dumps(detail,cls=Encoder),
        "EventBusName" : EVENT_BUS_NAME        
    }

    # pdb.set_trace()
    return event_bridge_event



#!/usr/bin/env python3


from setuptools import find_packages, setup


setup(
    author="ecomm warehouse Services",
    install_requires=[],
    license="MIT-0",
    name="ecom-wh-com",
    packages=find_packages(),
    setup_requires=["pytest-runner"],
    test_suite="tests",
    tests_require=["pytest"],
    version="0.0.4"
)